@@ -2,8 +2,10 @@ use std::convert::TryFrom;
 
 use syn::{Attribute, Ident, Result};
 
-use crate::attr::{parse_assign_str, Inflection};
-use crate::utils::parse_attrs;
+use crate::{
+    attr::{parse_assign_str, Inflection},
+    utils::parse_attrs,
+};
 
 #[derive(Default)]
 pub struct StructAttr {
