@@ -1,9 +1,11 @@
 use proc_macro2::TokenStream;
 use quote::quote;
-use syn::{Field, FieldsUnnamed, Result};
+use syn::{Field, FieldsUnnamed, Generics, Result};
 
 use crate::{
     attr::{FieldAttr, Inflection},
+    deps::Dependencies,
+    types::generics::format_type,
     DerivedTS,
 };
 
@@ -11,15 +13,16 @@ pub(crate) fn tuple(
     name: &str,
     rename_all: &Option<Inflection>,
     fields: &FieldsUnnamed,
+    generics: &Generics,
 ) -> Result<DerivedTS> {
     if rename_all.is_some() {
         syn_err!("`rename_all` is not applicable to tuple structs");
     }
 
     let mut formatted_fields = Vec::new();
-    let mut dependencies = Vec::new();
+    let mut dependencies = Dependencies::default();
     for field in &fields.unnamed {
-        format_field(&mut formatted_fields, &mut dependencies, field)?;
+        format_field(&mut formatted_fields, &mut dependencies, field, generics)?;
     }
 
     Ok(DerivedTS {
@@ -33,23 +36,20 @@ pub(crate) fn tuple(
             format!(
                 "type {} = {};",
                 #name,
-                Self::inline(0)
+                Self::inline()
             )
         },
         inline_flattened: None,
         name: name.to_owned(),
-        dependencies: quote! {
-            let mut dependencies = vec![];
-            #( #dependencies )*
-            dependencies
-        },
+        dependencies,
     })
 }
 
 fn format_field(
     formatted_fields: &mut Vec<TokenStream>,
-    dependencies: &mut Vec<TokenStream>,
+    dependencies: &mut Dependencies,
     field: &Field,
+    generics: &Generics,
 ) -> Result<()> {
     let ty = &field.ty;
     let FieldAttr {
@@ -76,23 +76,19 @@ fn format_field(
 
     formatted_fields.push(match &type_override {
         Some(o) => quote!(#o.to_owned()),
-        None if inline => quote!(<#ty as ts_rs::TS>::inline(0)),
-        None => quote!(<#ty as ts_rs::TS>::name()),
+        None if inline => quote!(<#ty as ts_rs::TS>::inline()),
+        None => format_type(ty, dependencies, generics),
     });
 
-    dependencies.push(match (inline, &type_override) {
-        (_, Some(_)) => quote!(),
-        (false, _) => quote! {
-            if <#ty as ts_rs::TS>::transparent() {
-                dependencies.append(&mut <#ty as ts_rs::TS>::dependencies());
-            } else {
-                dependencies.push((std::any::TypeId::of::<#ty>(), <#ty as ts_rs::TS>::name()));
-            }
-        },
-        (true, _) => quote! {
-            dependencies.append(&mut (<#ty as ts_rs::TS>::dependencies()));
-        },
-    });
+    match (inline, &type_override) {
+        (_, Some(_)) => (),
+        (false, _) => {
+            dependencies.push_or_append_from(ty);
+        }
+        (true, _) => {
+            dependencies.append_from(ty);
+        }
+    };
 
     Ok(())
 }
